@@ -2,24 +2,23 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.3.5.4_2-84gs
+es5id: 15.3.5.4_2-57gs
 description: >
     Strict mode - checking access to strict function caller from
-    non-strict function (non-strict function declaration called by
-    strict Function.prototype.call())
+    non-strict function (strict function declaration called by
+    non-strict eval)
 flags: [noStrict]
-features: [caller]
 ---*/
 
 function f() {
-  return gNonStrict();
-};
-(function() {
   "use strict";
-  f.call();
-})();
+  gNonStrict();
+};
 
+assert.throws(TypeError, function() {
+  eval("f();");
+});
 
 function gNonStrict() {
-  return gNonStrict.caller;
+  return gNonStrict.caller || gNonStrict.caller.throwTypeError;
 }
